.. :changelog:

History
-------

0.0.1 (26-04-2021)
---------------------

* First code creation


0.1.0 (11-05-2021)
------------------

* Initial release


0.1.1 (17-05-2021)
------------------

* Filtering out failed accounts from checking their update status


0.1.2 (17-05-2021)
------------------

* Fixed a timing issue with getting the active service catalog product on account creation.


0.2.0 (18-05-2021)
------------------

* Exposed governed and non governed regions and a small fix with latest update changes.


0.2.1 (18-05-2021)
------------------

* Dynamically retrieving updatable information about control tower.


0.2.2 (19-05-2021)
------------------

* Added some blocking on actions to prevent race conditions.
